Module config

Module config 

Constants

VERSION

Functions

build_startup_log
Single source of truth for startup log — always includes env.features.
enabled_features
maybe_startup_log
Unified startup log builder + gate used by all runtime modes.
should_emit_startup_log
Decide whether startup log should be emitted for this process. Startup is emitted when explicit startup logging is requested or any log filter is set.