Module store

Module store 

Modules

db
lock
postgres_store
redb_store
transaction
wallet

Structs

MigrationLog

Enums

StorageBackend
Storage backend enum dispatching to the active variant.

Traits

PayStore
Trait abstracting wallet + transaction storage operations.

Functions

create_postgres_backend
Create a postgres storage backend asynchronously.
create_storage_backend
Create a storage backend based on config and enabled features. Returns None if no storage backend is available (frontend-only mode). For postgres, performs async connection via block_in_place.