Input

Enum Input 

pub enum Input {
Show 26 variants WalletCreate {
Show 14 fields id: String, network: Network, label: Option<String>, mint_url: Option<String>, rpc_endpoints: Vec<String>, chain_id: Option<u64>, mnemonic_secret: Option<String>, btc_esplora_url: Option<String>, btc_network: Option<String>, btc_address_type: Option<String>, btc_backend: Option<BtcBackend>, btc_core_url: Option<String>, btc_core_auth_secret: Option<String>, btc_electrum_url: Option<String>,
}, LnWalletCreate { id: String, request: LnWalletCreateRequest, }, WalletClose { id: String, wallet: String, dangerously_skip_balance_check_and_may_lose_money: bool, }, WalletList { id: String, network: Option<Network>, }, Balance { id: String, wallet: Option<String>, network: Option<Network>, check: bool, }, Receive { id: String, wallet: String, network: Option<Network>, amount: Option<Amount>, onchain_memo: Option<String>, wait_until_paid: bool, wait_timeout_s: Option<u64>, wait_poll_interval_ms: Option<u64>, wait_sync_limit: Option<usize>, write_qr_svg_file: bool, min_confirmations: Option<u32>, }, ReceiveClaim { id: String, wallet: String, quote_id: String, }, CashuSend { id: String, wallet: Option<String>, amount: Amount, onchain_memo: Option<String>, local_memo: Option<BTreeMap<String, String>>, mints: Option<Vec<String>>, }, CashuReceive { id: String, wallet: Option<String>, token: String, }, Send { id: String, wallet: Option<String>, network: Option<Network>, to: String, onchain_memo: Option<String>, local_memo: Option<BTreeMap<String, String>>, mints: Option<Vec<String>>, }, Restore { id: String, wallet: String, }, WalletShowSeed { id: String, wallet: String, }, HistoryList { id: String, wallet: Option<String>, network: Option<Network>, onchain_memo: Option<String>, limit: Option<usize>, offset: Option<usize>, since_epoch_s: Option<u64>, until_epoch_s: Option<u64>, }, HistoryStatus { id: String, transaction_id: String, }, HistoryUpdate { id: String, wallet: Option<String>, network: Option<Network>, limit: Option<usize>, }, LimitAdd { id: String, limit: SpendLimit, }, LimitRemove { id: String, rule_id: String, }, LimitList { id: String, }, LimitSet { id: String, limits: Vec<SpendLimit>, }, WalletConfigShow { id: String, wallet: String, }, WalletConfigSet { id: String, wallet: String, label: Option<String>, rpc_endpoints: Vec<String>, chain_id: Option<u64>, }, WalletConfigTokenAdd { id: String, wallet: String, symbol: String, address: String, decimals: u8, }, WalletConfigTokenRemove { id: String, wallet: String, symbol: String, }, Config(ConfigPatch), Version, Close,
}

Variants



WalletCreate

Fields

network: Network
mint_url: Option<String>

Cashu mint URL (cashu only).

rpc_endpoints: Vec<String>

RPC endpoints for sol/evm providers.

chain_id: Option<u64>

EVM chain ID (evm only, default 8453 = Base).

mnemonic_secret: Option<String>
btc_esplora_url: Option<String>

Esplora API URL (btc only).

btc_network: Option<String>

BTC sub-network: “mainnet” | “signet” (btc only).

btc_address_type: Option<String>

BTC address type: “taproot” | “segwit” (btc only).

btc_backend: Option<BtcBackend>

BTC chain-source backend (btc only).

btc_core_url: Option<String>

Bitcoin Core RPC URL (btc core-rpc only).

btc_core_auth_secret: Option<String>

Bitcoin Core RPC auth (btc core-rpc only).

btc_electrum_url: Option<String>

Electrum server URL (btc electrum only).



LnWalletCreate



WalletClose

Fields

wallet: String
dangerously_skip_balance_check_and_may_lose_money: bool


WalletList

Fields

network: Option<Network>


Balance

Fields

wallet: Option<String>
network: Option<Network>
check: bool


Receive

Fields

wallet: String
network: Option<Network>
amount: Option<Amount>
onchain_memo: Option<String>
wait_until_paid: bool
wait_timeout_s: Option<u64>
wait_poll_interval_ms: Option<u64>
wait_sync_limit: Option<usize>
write_qr_svg_file: bool
min_confirmations: Option<u32>


ReceiveClaim

Fields

wallet: String
quote_id: String


CashuSend

Fields

wallet: Option<String>
amount: Amount
onchain_memo: Option<String>
mints: Option<Vec<String>>

Restrict to wallets on these mints (tried in order).



CashuReceive

Fields

wallet: Option<String>
token: String


Send

Fields

wallet: Option<String>
network: Option<Network>
onchain_memo: Option<String>
mints: Option<Vec<String>>

Restrict to wallets on these mints (cashu only).



Restore

Fields

wallet: String


WalletShowSeed

Fields

wallet: String


HistoryList

Fields

wallet: Option<String>
network: Option<Network>
onchain_memo: Option<String>
limit: Option<usize>
offset: Option<usize>
since_epoch_s: Option<u64>

Only include records created at or after this epoch second.

until_epoch_s: Option<u64>

Only include records created before this epoch second.



HistoryStatus

Fields

transaction_id: String


HistoryUpdate

Fields

wallet: Option<String>
network: Option<Network>
limit: Option<usize>


LimitAdd

Fields



LimitRemove

Fields

rule_id: String


LimitList

Fields



LimitSet

Fields

limits: Vec<SpendLimit>


WalletConfigShow

Fields

wallet: String


WalletConfigSet

Fields

wallet: String
rpc_endpoints: Vec<String>
chain_id: Option<u64>


WalletConfigTokenAdd

Fields

wallet: String
symbol: String
address: String
decimals: u8


WalletConfigTokenRemove

Fields

wallet: String
symbol: String


Config(ConfigPatch)



Version



Close

Implementations

Source

impl Input

pub fn is_local_only(&self) -> bool

Returns true if this input must only be handled locally (never via RPC).