pub struct SpendLimit {
pub rule_id: Option<String>,
pub scope: SpendScope,
pub network: Option<String>,
pub wallet: Option<String>,
pub window_s: u64,
pub max_spend: u64,
pub token: Option<String>,
}Fields
rule_id: Option<String>scope: SpendScopenetwork: Option<String>wallet: Option<String>window_s: u64max_spend: u64token: Option<String>Trait Implementations
Sourceimpl Clone for SpendLimit
impl Clone for SpendLimit
Sourcefn clone(&self) -> SpendLimit
fn clone(&self) -> SpendLimit
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SpendLimit
impl Debug for SpendLimit
Sourceimpl<'de> Deserialize<'de> for SpendLimit
impl<'de> Deserialize<'de> for SpendLimit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SpendLimit
impl JsonSchema for SpendLimit
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SpendLimit
impl RefUnwindSafe for SpendLimit
impl Send for SpendLimit
impl Sync for SpendLimit
impl Unpin for SpendLimit
impl UnsafeUnpin for SpendLimit
impl UnwindSafe for SpendLimit