Modules
Structs
Enums
- Storage
Backend - Storage backend enum dispatching to the active variant.
Traits
- PayStore
- Trait abstracting wallet + transaction storage operations.
Functions
- create_
postgres_ backend - Create a postgres storage backend asynchronously.
- create_
storage_ backend - Create a storage backend based on config and enabled features.
Returns None if no storage backend is available (frontend-only mode).
For postgres, performs async connection via
block_in_place.