Structs
- Afpay
RpcConfig - Amount
- Balance
Info - Cashu
Receive Result - Cashu
Send Quote Info - Cashu
Send Result - Close
Trace - Config
Patch - Downstream
Limit Node - Exchange
Rate Config - Exchange
Rate Source - History
Record - History
Status Info - LnWallet
Create Request - Pong
Trace - Rate
Limit Config - Rate limiting configuration for REST/RPC endpoints.
- Receive
Info - Restore
Result - Runtime
Config - Send
Quote Info - Send
Result - Spend
Limit - Spend
Limit Status - Trace
- Wallet
Balance Item - Wallet
Create Request - Wallet
Info - Wallet
Summary
Enums
Functions
- is_
bolt12_ offer - Returns true if the string looks like a BOLT12 offer (
lno1…), optionally with a?amount=<sats>suffix. Case-insensitive. - parse_
bolt12_ offer_ parts - Split a BOLT12 offer string into the raw offer and an optional amount-sats.
Accepts
lno1...orlno1...?amount=1000. Case-insensitive prefix detection.